@@ -94,7 +94,7 @@ int BarcodeDetector::analyseImage(char *buffer, char *fourcc, int bpp) {
 
             this->dmtx_thread.hasFoundBarcode = false; // reset this so we don't look at this data again
 
-            emit imageAnalysed(TYPE_DMTX, QString(this->dmtx_thread.thread_output).toUtf8()); // *output
+            emit imageAnalysed(TYPE_DMTX, QString::fromUtf8(this->dmtx_thread.thread_output)); // *output
 
             return ZBAR_QRCODE; // QR is also 2D so achieves the same effect //BARCODE_TYPE_DMTX;
 
@@ -146,7 +146,7 @@ int BarcodeDetector::analyseImage(char *buffer, char *fourcc, int bpp) {
             qDebug() << "analyse_image(): found ZBar barcode, zbar_thread.thread_output=" << QString(this->zbar_thread.thread_output);
             qDebug() << "analyse_image(): found ZBar barcode, zbar_thread.barcode_type=" << QString(this->zbar_thread.barcode_type);
 
-            emit imageAnalysed(QString(this->zbar_thread.barcode_type).toUtf8(),QString(this->zbar_thread.thread_output).toUtf8()); // *output
+            emit imageAnalysed(QString::fromUtf8(this->zbar_thread.barcode_type),QString::fromUtf8(this->zbar_thread.thread_output)); // *output
 
             return 1; // not sure this makes any odds anymore anyway.
 
